History
-------

unreleased (YYYY-MM-DD)
+++++++++++++++++++++++

0.1.4 (2020-09-15)
++++++++++++++++++

* (PR #26, 2020-09-15) build(deps): bump uritemplate from 3.0.0 to 3.0.1
* (PR #39, 2020-09-15) config: Add PyPI package uploading to CI
* (PR #23, 2020-09-15) build(deps): bump twine from 1.13.0 to 3.2.0
* (PR #38, 2020-09-15) build(deps): bump setuptools from 41.0.1 to 50.3.0
* (PR #27, 2020-07-09) config: Verify Python dependency compatibility in CI
* (PR #28, 2020-07-09) requirements: update dependencies of 'flake8'
* (PR #24, 2020-07-08) build(deps): bump flake8 from 3.7.8 to 3.8.3
* (PR #22, 2020-07-07) config: Add configuration for GitHub Dependabot
* (PR #21, 2020-06-18) Update readme
* (PR #20, 2020-06-09) requirements: update 'httplib2'

0.1.3 (2020-06-08)
++++++++++++++++++

* (PR #16, 2020-06-08) config: Add support for multiple Python versions to CircleCI
* (PR #18, 2020-06-08) requirements: update 'tox' (test)
* (PR #17, 2020-06-08) Add Python 3.8 support

0.1.2 (2019-07-09)
++++++++++++++++++

* (PR #14, 2019-07-09) requirements: update main depedencies
* (PR #13, 2019-07-09) requirements: update all those for 'test' and 'release'
* (PR #12, 2019-05-14) requirements: update 'urllib3'

0.1.1 (2019-03-07)
++++++++++++++++++

* (PR #9, 2019-03-07) Misc fixes and improvements to config and test setup
* (PR #8, 2019-03-07) Update requirements

0.1.0 (2019-01-24)
++++++++++++++++++

* First implementation.
* First release on PyPI.
